#ifndef NT2_INCLUDE_FUNCTIONS_MINNUMMAG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MINNUMMAG_HPP_INCLUDED

#include <nt2/ieee/include/functions/minnummag.hpp>

#endif
